@@ -9,7 +9,7 @@
 #
 package CatalystX::Action::ExtJS::Serialize;
 BEGIN {
-  $CatalystX::Action::ExtJS::Serialize::VERSION = '1.120000';
+  $CatalystX::Action::ExtJS::Serialize::VERSION = '1.122000';
 }
 # ABSTRACT: Handle responses from uploads
 use strict;
@@ -20,7 +20,7 @@ use base 'Catalyst::Action::Serialize';
 sub execute {
     my ( $self, $controller, $c ) = @_;
     $self->next::method( $controller, $c );
-    if ( $c->stash->{upload} ) {
+    if ( $c->stash->{upload} && $c->stash->{upload} eq 'true' ) {
         $c->res->content_type('text/html');
         my $body = $c->res->body;
         $body =~ s/&quot;/\&quot;/;
@@ -41,7 +41,7 @@ CatalystX::Action::ExtJS::Serialize - Handle responses from uploads
 
 =head1 VERSION
 
-version 1.120000
+version 1.122000
 
 =head1 PUBLIC METHODS
 
